@@ -47,8 +47,8 @@ flow.vat <- stats::ts(c(
 6.7,
 6.9,
 5.34,
-4.34,
-4.9,
+5.34,
+5.9,
 6.3,
 6.9,
 7.92,
@@ -425,7 +425,6 @@ flow.vat <- stats::ts(c(
 9.68,
 9.68,
 9.68,
-9.68,
 9.46,
 9.24,
 8.8,
@@ -791,7 +790,6 @@ flow.vat <- stats::ts(c(
 3.98,
 4.31,
 4.31,
-4.31,
 3.67,
 4.31,
 6.1,
@@ -1097,10 +1095,10 @@ flow.vat <- stats::ts(c(
 5.16,
 5.34,
 5.34),
-start=c(1972,1),end=c(1974,365),frequency=365)
+start=c(1972,1),frequency=365)
 flow.jok <- stats::ts(c(
 30.2,
-29.0,
+29,
 28.4,
 27.8,
 27.8,
@@ -1128,11 +1126,11 @@ flow.jok <- stats::ts(c(
 26.2,
 26.7,
 28.4,
-29.0,
+29,
 27.8,
 27.3,
 26.7,
-26.7,
+26.2,
 25.7,
 26.2,
 26.2,
@@ -1155,7 +1153,7 @@ flow.jok <- stats::ts(c(
 26.7,
 26.7,
 26.7,
-26.7,
+26.2,
 25.7,
 25.7,
 25.2,
@@ -1178,7 +1176,7 @@ flow.jok <- stats::ts(c(
 28.4,
 31.4,
 30.2,
-29.0,
+29,
 28.4,
 27.8,
 26.7,
@@ -1215,35 +1213,35 @@ flow.jok <- stats::ts(c(
 30.2,
 41.7,
 51.7,
-44.0,
-41.0,
+44,
+41,
 35.7,
 30.8,
 27.8,
-29.0,
-29.0,
+29,
+29,
 28.4,
 27.8,
 34.4,
-47.0,
+47,
 59.1,
-101.0,
-103.0,
-90.0,
-113.0,
-121.0,
-104.0,
+101,
+103,
+90,
+113,
+121,
+104,
 94.8,
 77.4,
-83.0,
+83,
 81.6,
 80.2,
 81.6,
-90.0,
-103.0,
-111.0,
-109.0,
-103.0,
+90,
+103,
+111,
+109,
+103,
 99.6,
 91.6,
 66.6,
@@ -1262,12 +1260,12 @@ flow.jok <- stats::ts(c(
 57.4,
 63.4,
 67.8,
-69.0,
+69,
 70.2,
 84.4,
-90.0,
+90,
 78.8,
-60.0,
+60,
 48.5,
 42.4,
 41.7,
@@ -1295,13 +1293,13 @@ flow.jok <- stats::ts(c(
 61.7,
 61.7,
 67.8,
-60.0,
+60,
 62.6,
 61.7,
 61.7,
 63.4,
 60.9,
-60.0,
+60,
 58.3,
 54.9,
 53.3,
@@ -1316,9 +1314,9 @@ flow.jok <- stats::ts(c(
 51.7,
 46.2,
 43.2,
-41.0,
+41,
 39.6,
-37.0,
+37,
 36.4,
 35.7,
 35.7,
@@ -1329,8 +1327,8 @@ flow.jok <- stats::ts(c(
 57.4,
 50.1,
 45.4,
-41.0,
-41.0,
+41,
+41,
 40.2,
 37.6,
 46.2,
@@ -1358,36 +1356,36 @@ flow.jok <- stats::ts(c(
 34.4,
 41.7,
 47.7,
-44.0,
+44,
 38.3,
 39.6,
-37.0,
+37,
 37.6,
 38.9,
 36.4,
 37.6,
-44.0,
-41.0,
+44,
+41,
 38.9,
 39.6,
 38.9,
-37.0,
+37,
 35.7,
 34.4,
-32.0,
+32,
 33.2,
-32.0,
+32,
 34.4,
 41.7,
 36.4,
 33.8,
 32.6,
-32.0,
-29.0,
+32,
+29,
 35.7,
 38.9,
 33.2,
-32.0,
+32,
 35.7,
 33.8,
 34.4,
@@ -1400,11 +1398,11 @@ flow.jok <- stats::ts(c(
 27.8,
 27.8,
 25.7,
-22.0,
+22,
 28.4,
 30.2,
 29.6,
-29.0,
+29,
 28.4,
 26.7,
 27.3,
@@ -1457,7 +1455,7 @@ flow.jok <- stats::ts(c(
 28.4,
 28.4,
 27.8,
-29.0,
+29,
 29.6,
 30.8,
 30.2,
@@ -1488,11 +1486,11 @@ flow.jok <- stats::ts(c(
 30.2,
 29.6,
 29.6,
-29.0,
+29,
 28.4,
 27.3,
 27.3,
-29.0,
+29,
 28.4,
 27.8,
 27.3,
@@ -1543,7 +1541,7 @@ flow.jok <- stats::ts(c(
 27.3,
 28.4,
 29.6,
-29.0,
+29,
 29.6,
 30.8,
 29.6,
@@ -1568,7 +1566,7 @@ flow.jok <- stats::ts(c(
 24.6,
 26.2,
 27.8,
-32.0,
+32,
 38.3,
 36.4,
 35.7,
@@ -1577,7 +1575,7 @@ flow.jok <- stats::ts(c(
 67.8,
 64.3,
 64.3,
-60.0,
+60,
 60.9,
 55.7,
 49.3,
@@ -1591,7 +1589,7 @@ flow.jok <- stats::ts(c(
 29.6,
 29.6,
 29.6,
-32.0,
+32,
 30.2,
 29.6,
 27.3,
@@ -1621,27 +1619,27 @@ flow.jok <- stats::ts(c(
 38.3,
 42.4,
 47.7,
-47.0,
+47,
 48.5,
 49.3,
 47.7,
 41.7,
 38.9,
-37.0,
+37,
 35.1,
 34.4,
 36.4,
 49.3,
 65.5,
 87.2,
-109.0,
-113.0,
-98.0,
-109.0,
-127.0,
-125.0,
-115.0,
-115.0,
+109,
+113,
+98,
+109,
+127,
+125,
+115,
+115,
 91.6,
 87.2,
 85.8,
@@ -1655,23 +1653,23 @@ flow.jok <- stats::ts(c(
 63.4,
 62.6,
 66.6,
-76.0,
-90.0,
-116.0,
-111.0,
-132.0,
-123.0,
-113.0,
-98.0,
+76,
+90,
+116,
+111,
+132,
+123,
+113,
+98,
 87.2,
 78.8,
-69.0,
+69,
 63.4,
 61.7,
 62.6,
 62.6,
 64.3,
-76.0,
+76,
 84.4,
 84.4,
 84.4,
@@ -1684,7 +1682,7 @@ flow.jok <- stats::ts(c(
 59.1,
 64.3,
 47.7,
-44.0,
+44,
 41.7,
 41.7,
 43.2,
@@ -1710,16 +1708,16 @@ flow.jok <- stats::ts(c(
 55.7,
 53.3,
 49.3,
-47.0,
+47,
 43.2,
 42.4,
-41.0,
+41,
 39.6,
 39.6,
 36.4,
 35.7,
 37.6,
-44.0,
+44,
 55.7,
 70.2,
 63.4,
@@ -1730,7 +1728,7 @@ flow.jok <- stats::ts(c(
 47.7,
 41.7,
 38.3,
-37.0,
+37,
 40.2,
 49.3,
 44.7,
@@ -1740,9 +1738,9 @@ flow.jok <- stats::ts(c(
 35.1,
 50.9,
 60.9,
-60.0,
+60,
 42.4,
-44.0,
+44,
 43.2,
 42.4,
 35.1,
@@ -1753,9 +1751,9 @@ flow.jok <- stats::ts(c(
 32.6,
 39.8,
 30.2,
-29.0,
-29.0,
-29.0,
+29,
+29,
+29,
 30.2,
 31.4,
 30.2,
@@ -1763,7 +1761,7 @@ flow.jok <- stats::ts(c(
 32.6,
 33.2,
 30.2,
-29.0,
+29,
 28.4,
 30.8,
 35.1,
@@ -1777,12 +1775,12 @@ flow.jok <- stats::ts(c(
 31.4,
 35.1,
 35.1,
-32.0,
+32,
 31.4,
 30.2,
 27.8,
-29.0,
-29.0,
+29,
+29,
 27.3,
 26.2,
 27.3,
@@ -1795,15 +1793,15 @@ flow.jok <- stats::ts(c(
 27.8,
 27.8,
 28.4,
-29.0,
-29.0,
-29.0,
+29,
+29,
+29,
 28.4,
 29.6,
 35.7,
 29.6,
 28.4,
-29.0,
+29,
 27.8,
 27.8,
 27.8,
@@ -1819,12 +1817,12 @@ flow.jok <- stats::ts(c(
 27.8,
 27.8,
 27.8,
-32.0,
+32,
 27.8,
 27.8,
 27.8,
 28.4,
-29.0,
+29,
 28.4,
 28.4,
 27.8,
@@ -1871,12 +1869,12 @@ flow.jok <- stats::ts(c(
 23.6,
 22.5,
 22.5,
-22.0,
-22.0,
-22.0,
-22.0,
-22.0,
-22.0,
+22,
+22,
+22,
+22,
+22,
+22,
 22.5,
 24.6,
 24.6,
@@ -1886,7 +1884,7 @@ flow.jok <- stats::ts(c(
 24.6,
 26.2,
 25.7,
-32.0,
+32,
 26.2,
 26.7,
 25.7,
@@ -1897,12 +1895,12 @@ flow.jok <- stats::ts(c(
 24.1,
 24.6,
 27.3,
-32.0,
-32.0,
+32,
+32,
 30.8,
 29.6,
 29.6,
-29.0,
+29,
 27.8,
 26.7,
 26.7,
@@ -1925,37 +1923,37 @@ flow.jok <- stats::ts(c(
 43.2,
 59.1,
 85.8,
-116.0,
-121.0,
+116,
+121,
 78.8,
 57.4,
 51.7,
 47.7,
-44.0,
+44,
 40.2,
-44.0,
+44,
 60.9,
 64.3,
-69.0,
-76.0,
-69.0,
+69,
+76,
+69,
 67.8,
 78.8,
 71.3,
 64.3,
 81.6,
-141.0,
-141.0,
-90.0,
-76.0,
-69.0,
+141,
+141,
+90,
+76,
+69,
 60.9,
 59.1,
 57.4,
 57.4,
 54.1,
 52.5,
-47.0,
+47,
 43.2,
 38.9,
 35.1,
@@ -1965,14 +1963,14 @@ flow.jok <- stats::ts(c(
 52.5,
 71.3,
 73.7,
-90.0,
+90,
 96.4,
 99.6,
-116.0,
+116,
 99.6,
 94.8,
-113.0,
-76.0,
+113,
+76,
 78.8,
 81.6,
 60.9,
@@ -1983,7 +1981,7 @@ flow.jok <- stats::ts(c(
 42.4,
 54.1,
 57.4,
-76.0,
+76,
 72.5,
 71.3,
 71.3,
@@ -1993,10 +1991,10 @@ flow.jok <- stats::ts(c(
 46.2,
 46.2,
 50.1,
-143.0,
-134.0,
+143,
+134,
 84.4,
-76.0,
+76,
 67.8,
 62.6,
 55.7,
@@ -2004,20 +2002,20 @@ flow.jok <- stats::ts(c(
 53.3,
 62.6,
 84.4,
-113.0,
+113,
 93.2,
 78.8,
 71.3,
 59.1,
 49.3,
-44.0,
+44,
 42.4,
-47.0,
+47,
 48.5,
 44.7,
 43.2,
 40.2,
-41.0,
+41,
 49.3,
 53.3,
 65.5,
@@ -2059,22 +2057,22 @@ flow.jok <- stats::ts(c(
 46.2,
 44.7,
 43.2,
-41.0,
-41.0,
-44.0,
-41.0,
-37.0,
+41,
+41,
+44,
+41,
+37,
 33.8,
 32.6,
-32.0,
+32,
 31.4,
 30.2,
 30.8,
-32.0,
+32,
 30.8,
 33.8,
 38.3,
-44.0,
+44,
 49.3,
 49.3,
 53.3,
@@ -2083,7 +2081,7 @@ flow.jok <- stats::ts(c(
 35.7,
 33.2,
 32.6,
-32.0,
+32,
 31.4,
 35.7,
 33.8,
@@ -2091,10 +2089,10 @@ flow.jok <- stats::ts(c(
 30.8,
 30.8,
 27.8,
-29.0,
-29.0,
+29,
+29,
 27.8,
-29.0,
+29,
 28.4,
 28.4,
 27.8,
@@ -2109,24 +2107,24 @@ flow.jok <- stats::ts(c(
 28.4,
 28.4,
 27.8,
-27.8,
+27.3,
 27.8,
 26.7,
 26.7,
 27.8,
 28.4,
 33.8,
-41.0,
+41,
 38.3,
-29.0,
-29.0,
+29,
+29,
 29.6,
-29.0,
+29,
 28.4,
 28.4,
 27.3,
-32.0,
-29.0,
+32,
+29,
 28.4,
 27.8,
 26.7,
@@ -2136,11 +2134,11 @@ flow.jok <- stats::ts(c(
 31.4,
 29.6,
 28.4,
-29.0,
+29,
 35.7,
 54.1,
-29.0,
-29.0,
+29,
+29,
 30.2,
 28.4,
 27.8,
@@ -2194,20 +2192,20 @@ flow.jok <- stats::ts(c(
 24.6,
 24.6,
 24.6,
-25.7),
-start=c(1972,1),end=c(1974,365),frequency=365)                 
+25.70),
+start=c(1972,1),frequency=365)				   
 prec <- stats::ts(c(
 8.1,
 4.4,
-7.0,
-0.0,
-0.0,
-0.0,
+7,
+0,
+0,
+0,
 1.9,
 1.2,
-0.0,
+0,
 0.1,
-0.0,
+0,
 0.2,
 1.8,
 0.2,
@@ -2215,35 +2213,35 @@ prec <- stats::ts(c(
 0.2,
 1.5,
 9.2,
-1.0,
+1,
 0.2,
 0.4,
 2.5,
 3.3,
 0.2,
 0.1,
-0.0,
-0.0,
+0,
+0,
 4.8,
 19.4,
 0.9,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.2,
 0.1,
 0.1,
-0.0,
+0,
 3.8,
-0.0,
+0,
 0.1,
 0.1,
 0.1,
 0.2,
-0.0,
-0.0,
+0,
+0,
 2.9,
 2.1,
 6.7,
@@ -2256,13 +2254,13 @@ prec <- stats::ts(c(
 0.3,
 0.3,
 0.2,
-0.0,
+0,
 1.2,
 0.1,
 0.5,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 1.7,
 0.5,
 1.8,
@@ -2270,8 +2268,8 @@ prec <- stats::ts(c(
 16.1,
 0.6,
 0.2,
-4.0,
-4.0,
+4,
+4,
 1.3,
 22.4,
 35.7,
@@ -2281,34 +2279,34 @@ prec <- stats::ts(c(
 0.1,
 1.1,
 6.5,
-7.0,
+7,
 0.6,
 0.2,
 0.2,
 0.1,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 3.3,
 0.3,
 0.1,
 0.1,
-0.0,
+0,
 1.6,
 0.3,
 1.9,
-0.0,
-0.0,
+0,
+0,
 0.3,
 1.3,
 0.1,
-0.0,
+0,
 1.7,
 0.1,
 0.1,
 0.1,
 0.2,
-0.0,
+0,
 0.1,
 0.1,
 0.2,
@@ -2317,37 +2315,37 @@ prec <- stats::ts(c(
 0.2,
 3.7,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 1.8,
 20.7,
 0.1,
 0.1,
-0.0,
-0.0,
+0,
+0,
 0.1,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.2,
 0.2,
 5.6,
 1.8,
-7.0,
+7,
 0.3,
 0.1,
 0.2,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.1,
 0.2,
 0.8,
-0.0,
-0.0,
+0,
+0,
 0.2,
 0.2,
 2.6,
@@ -2356,16 +2354,16 @@ prec <- stats::ts(c(
 0.1,
 0.6,
 0.4,
-0.0,
+0,
 0.5,
-0.0,
-0.0,
+0,
+0,
 1.3,
-0.0,
+0,
 4.4,
 1.2,
 13.8,
-0.0,
+0,
 0.9,
 0.3,
 0.3,
@@ -2377,7 +2375,7 @@ prec <- stats::ts(c(
 2.2,
 4.4,
 1.6,
-7.0,
+7,
 2.2,
 1.7,
 0.6,
@@ -2395,34 +2393,34 @@ prec <- stats::ts(c(
 10.2,
 4.2,
 8.4,
-0.0,
+0,
 2.8,
-0.0,
+0,
 7.2,
 2.5,
 4.8,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 1.4,
 2.9,
 5.5,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.2,
-0.0,
-0.0,
+0,
+0,
 1.9,
 1.3,
 0.1,
 0.1,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.4,
-8.0,
+8,
 10.8,
 3.6,
 0.1,
@@ -2435,74 +2433,74 @@ prec <- stats::ts(c(
 0.2,
 0.3,
 0.2,
-5.0,
+5,
 4.9,
 2.1,
-6.0,
+6,
 3.9,
 0.2,
 7.5,
 0.6,
-0.0,
+0,
 0.4,
 1.8,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
 1.9,
 1.7,
 0.1,
 0.4,
-0.0,
+0,
 1.2,
 1.2,
 1.3,
-7.0,
+7,
 0.2,
 2.6,
 0.9,
-25.0,
+25,
 0.6,
-0.0,
+0,
 3.3,
-1.0,
+1,
 5.4,
 5.2,
 0.2,
 0.7,
 11.3,
-0.0,
+0,
 6.2,
 6.5,
-0.0,
+0,
 9.6,
-0.0,
+0,
 0.6,
 3.7,
-54.0,
+54,
 3.4,
 0.1,
 1.5,
 16.2,
-0.0,
+0,
 0.1,
-0.0,
-0.0,
+0,
+0,
 4.3,
 0.2,
 0.3,
-1.0,
-0.0,
+1,
+0,
 0.1,
 0.1,
 24.9,
 3.5,
 1.2,
 2.9,
-0.0,
+0,
 2.2,
 0.7,
 3.7,
@@ -2510,7 +2508,7 @@ prec <- stats::ts(c(
 3.8,
 6.7,
 0.2,
-0.0,
+0,
 0.8,
 2.4,
 0.5,
@@ -2518,36 +2516,36 @@ prec <- stats::ts(c(
 0.2,
 0.3,
 0.2,
-0.0,
+0,
 1.1,
 0.4,
 0.2,
 0.9,
 0.2,
-0.0,
+0,
 9.9,
-18.0,
+18,
 14.3,
 0.8,
 4.1,
 4.6,
 1.9,
-0.0,
+0,
 1.3,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.1,
 0.1,
-0.0,
-0.0,
+0,
+0,
 0.2,
 0.1,
-0.0,
-0.0,
+0,
+0,
 0.5,
-0.0,
+0,
 1.9,
 2.3,
 18.5,
@@ -2555,7 +2553,7 @@ prec <- stats::ts(c(
 8.4,
 4.2,
 1.4,
-0.0,
+0,
 2.6,
 11.7,
 0.2,
@@ -2577,34 +2575,34 @@ prec <- stats::ts(c(
 1.7,
 2.4,
 0.1,
-0.0,
+0,
 1.5,
 0.9,
 0.7,
 9.2,
 0.7,
-0.0,
+0,
 0.6,
-1.0,
+1,
 1.8,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 9.4,
-0.0,
+0,
 1.2,
-0.0,
-0.0,
+0,
+0,
 8.2,
 13.7,
 10.7,
 1.3,
 6.6,
-0.0,
+0,
 1.5,
-1.0,
-0.0,
-9.0,
+1,
+0,
+9,
 0.8,
 1.6,
 1.9,
@@ -2616,81 +2614,81 @@ prec <- stats::ts(c(
 2.8,
 11.1,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
-3.0,
+0,
+0,
+0,
+0,
+3,
 6.7,
 4.3,
-0.0,
+0,
 1.6,
-1.0,
+1,
 0.1,
-0.0,
+0,
 1.9,
 20.7,
 0.2,
-0.0,
+0,
 24.3,
-5.0,
+5,
 0.2,
 0.1,
 10.3,
 2.6,
-0.0,
+0,
 0.1,
-0.0,
+0,
 0.1,
 7.5,
-6.0,
+6,
 0.1,
 1.2,
-0.0,
+0,
 3.9,
 12.9,
 0.1,
 2.9,
-2.0,
-0.0,
-0.0,
-0.0,
+2,
+0,
+0,
+0,
 0.1,
 4.3,
 0.1,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-1.0,
+0,
+0,
+0,
+0,
+0,
+0,
+0,
+1,
 0.8,
 0.8,
 1.1,
 1.5,
 0.1,
 0.1,
-1.0,
+1,
 0.2,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
 0.1,
-0.0,
+0,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.1,
-0.0,
-0.0,
-3.0,
+0,
+0,
+3,
 0.1,
 0.2,
 0.2,
@@ -2701,23 +2699,23 @@ prec <- stats::ts(c(
 16.1,
 16.3,
 0.2,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
+0,
+0,
 6.3,
 0.1,
 2.1,
 2.4,
 0.1,
 0.2,
-0.0,
-0.0,
+0,
+0,
 0.8,
-0.0,
+0,
 2.9,
 0.1,
 2.4,
@@ -2726,8 +2724,8 @@ prec <- stats::ts(c(
 0.5,
 1.2,
 0.2,
-0.0,
-0.0,
+0,
+0,
 1.7,
 14.4,
 2.1,
@@ -2737,13 +2735,13 @@ prec <- stats::ts(c(
 1.3,
 2.6,
 2.9,
-0.0,
+0,
 0.2,
-9.0,
+9,
 2.3,
 1.6,
 2.4,
-0.0,
+0,
 0.1,
 1.6,
 3.6,
@@ -2754,51 +2752,51 @@ prec <- stats::ts(c(
 0.2,
 1.1,
 0.1,
-0.0,
+0,
 0.3,
 0.4,
 8.9,
 0.1,
 0.4,
 0.2,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 1.9,
 0.2,
 1.2,
 0.1,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 11.1,
 1.4,
 1.4,
-22.0,
-2.0,
-0.0,
+22,
+2,
+0,
 0.8,
 10.1,
 4.7,
-0.0,
+0,
 13.6,
 2.5,
 2.7,
 0.3,
 0.4,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
+0,
+0,
 3.4,
 6.3,
 0.4,
@@ -2815,55 +2813,55 @@ prec <- stats::ts(c(
 0.1,
 0.2,
 0.1,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.1,
 3.9,
 0.2,
-0.0,
+0,
 0.1,
 1.7,
 0.4,
 0.2,
 0.8,
-0.0,
-0.0,
+0,
+0,
 5.7,
-18.0,
-12.0,
-2.0,
-0.0,
+18,
+12,
+2,
+0,
 0.2,
 0.1,
 1.2,
 3.8,
-13.0,
+13,
 0.1,
 3.5,
 0.2,
 0.1,
 6.4,
-1.0,
-0.0,
-0.0,
+1,
+0,
+0,
 0.2,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 4.3,
 5.1,
-7.0,
+7,
 4.1,
 17.7,
 5.4,
-0.0,
+0,
 7.8,
 20.8,
 37.6,
@@ -2872,65 +2870,65 @@ prec <- stats::ts(c(
 1.2,
 0.5,
 0.2,
-0.0,
+0,
 11.4,
 9.8,
-2.0,
+2,
 0.1,
 0.1,
 2.9,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
 0.1,
 0.3,
 0.7,
 2.2,
 2.1,
 0.1,
-0.0,
-0.0,
+0,
+0,
 1.7,
 0.3,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.1,
 5.6,
 1.2,
 2.8,
 6.1,
 0.4,
-0.0,
+0,
 0.3,
 4.5,
 0.9,
-0.0,
+0,
 4.6,
 0.8,
-0.0,
+0,
 2.5,
 3.9,
 0.4,
-0.0,
-0.0,
+0,
+0,
 2.3,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 3.6,
 0.2,
 4.9,
 0.3,
 1.9,
 0.5,
-0.0,
-3.0,
+0,
+3,
 0.3,
-0.0,
+0,
 2.2,
 0.7,
 2.9,
@@ -2941,12 +2939,12 @@ prec <- stats::ts(c(
 0.1,
 1.6,
 0.1,
-0.0,
-0.0,
+0,
+0,
 1.6,
 0.8,
 2.5,
-0.0,
+0,
 30.8,
 6.8,
 1.9,
@@ -2955,26 +2953,26 @@ prec <- stats::ts(c(
 6.7,
 1.6,
 3.3,
-3.0,
+3,
 0.2,
-0.0,
+0,
 0.3,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
 0.1,
 0.1,
-0.0,
+0,
 1.8,
 0.6,
 0.7,
 0.2,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.5,
 3.6,
 2.3,
@@ -2982,7 +2980,7 @@ prec <- stats::ts(c(
 1.9,
 1.8,
 1.5,
-18.0,
+18,
 1.8,
 60.3,
 17.3,
@@ -2999,95 +2997,95 @@ prec <- stats::ts(c(
 0.9,
 0.2,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.8,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
 4.3,
 5.8,
 3.4,
 0.1,
-0.0,
+0,
 1.1,
-12.0,
+12,
 5.1,
 77.7,
 25.6,
-3.0,
-4.0,
+3,
+4,
 10.8,
 5.7,
-10.0,
+10,
 10.3,
 10.5,
 3.2,
-0.0,
+0,
 0.7,
 0.4,
-2.0,
+2,
 0.9,
 0.4,
 0.5,
-0.0,
-0.0,
+0,
+0,
 5.4,
 0.4,
-4.0,
-0.0,
+4,
+0,
 0.6,
 0.6,
 6.4,
-6.0,
+6,
 0.5,
 0.1,
-0.0,
-0.0,
+0,
+0,
 0.4,
 6.1,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
+0,
+0,
+0,
+0,
 1.1,
 3.6,
 0.1,
 0.1,
 9.6,
-1.0,
+1,
 0.1,
 0.6,
-0.0,
-0.0,
+0,
+0,
 0.6,
 0.4,
-0.0,
-0.0,
+0,
+0,
 0.4,
 3.6,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.1,
 0.6,
-2.0,
+2,
 3.9,
 0.9,
 2.9,
 1.4,
 0.1,
-0.0,
-0.0,
+0,
+0,
 13.4,
 2.9,
 5.7,
@@ -3100,63 +3098,63 @@ prec <- stats::ts(c(
 3.8,
 6.2,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
+0,
 1.2,
-0.0,
-0.0,
+0,
+0,
 0.1,
 2.5,
 5.4,
 1.2,
-0.0,
+0,
 0.9,
 0.1,
-2.0,
+2,
 5.7,
 5.5,
 13.4,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
+0,
 3.6,
 0.2,
 0.4,
 0.2,
 2.7,
 0.2,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 1.4,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 2.1,
 0.2,
 0.5,
 0.2,
-0.0,
-1.0,
+0,
+1,
 0.6,
 2.9,
 10.2,
-3.0,
+3,
 2.1,
-0.0,
-0.0,
+0,
+0,
 0.1,
 0.1,
 0.2,
-0.0,
-0.0,
+0,
+0,
 0.1,
 2.8,
 1.5,
@@ -3167,7 +3165,7 @@ prec <- stats::ts(c(
 0.4,
 0.7,
 0.1,
-0.0,
+0,
 0.8,
 1.3,
 10.2,
@@ -3192,25 +3190,25 @@ prec <- stats::ts(c(
 0.1,
 0.1,
 0.1,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
 0.2,
 0.2,
-0.0,
+0,
 0.1,
-0.0,
+0,
 2.4,
-0.0,
+0,
 0.1,
 0.2,
 0.3,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
 0.1,
-0.0,
+0,
 0.2,
 0.1,
 6.3,
@@ -3221,23 +3219,23 @@ prec <- stats::ts(c(
 6.3,
 0.1,
 0.2,
-0.0,
-0.0,
-15.0,
+0,
+0,
+15,
 25.9,
 0.2,
 10.8,
-1.0,
-0.0,
+1,
+0,
 3.5,
 1.3,
 1.9,
-2.0,
-0.0,
+2,
+0,
 0.1,
-0.0,
+0,
 18.5,
-7.0,
+7,
 1.8,
 4.5,
 0.3,
@@ -3249,25 +3247,25 @@ prec <- stats::ts(c(
 0.5,
 0.2,
 0.2,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
-0.0,
+0,
+0,
+0,
+0,
+0,
+0,
 0.8,
 0.7,
 0.2,
 3.5,
-0.0,
-0.0,
+0,
+0,
 1.6,
 2.8,
 1.1,
 0.2,
 1.2,
 0.1,
-4.0,
+4,
 0.3,
 3.7,
 1.1,
@@ -3283,37 +3281,37 @@ prec <- stats::ts(c(
 0.1,
 0.4,
 1.2,
-0.0,
-0.0,
+0,
+0,
 0.4,
 0.1,
-0.0,
-0.0,
+0,
+0,
 7.1,
 0.1,
 0.3,
 8.1),
-start=c(1972,1),end=c(1974,365),frequency=365)             
+start=c(1972,1),frequency=365)			   
 temp <- stats::ts(c(
 0.9,
 1.6,
 0.1,
 0.6,
-2.0,
+2,
 0.8,
 1.4,
 1.3,
 2.2,
 0.1,
-3.0,
+3,
 -0.2,
 -2.6,
 -3.8,
 0.9,
 1.9,
 -0.4,
--6.0,
--5.0,
+-6,
+-5,
 -4.6,
 -5.3,
 -7.3,
@@ -3365,31 +3363,31 @@ temp <- stats::ts(c(
 -0.4,
 -3.9,
 -1.2,
--4.0,
+-4,
 -4.8,
 -7.8,
 -3.1,
 -4.6,
 2.2,
-1.0,
+1,
 -1.6,
 -3.2,
 0.1,
 -5.2,
 -6.5,
 -5.3,
-0.0,
+0,
 -6.8,
 -6.9,
--5.0,
+-5,
 -9.4,
 -9.4,
 -10.4,
 -8.4,
 0.9,
--7.0,
+-7,
 -11.7,
--9.0,
+-9,
 -7.9,
 -8.4,
 -9.8,
@@ -3405,12 +3403,12 @@ temp <- stats::ts(c(
 0.1,
 0.5,
 0.9,
-1.0,
+1,
 0.7,
 2.4,
-3.0,
+3,
 2.7,
-0.0,
+0,
 -0.2,
 -0.3,
 -3.2,
@@ -3421,13 +3419,13 @@ temp <- stats::ts(c(
 -0.5,
 0.8,
 2.2,
-3.0,
+3,
 4.7,
-4.0,
+4,
 3.5,
 4.4,
 4.3,
-4.0,
+4,
 2.9,
 1.8,
 1.8,
@@ -3460,7 +3458,7 @@ temp <- stats::ts(c(
 6.2,
 8.5,
 5.5,
-7.0,
+7,
 4.7,
 2.3,
 1.3,
@@ -3477,7 +3475,7 @@ temp <- stats::ts(c(
 5.2,
 6.2,
 6.5,
-7.0,
+7,
 6.1,
 1.9,
 3.5,
@@ -3497,9 +3495,9 @@ temp <- stats::ts(c(
 6.8,
 6.7,
 7.9,
-7.0,
+7,
 5.8,
-6.0,
+6,
 6.1,
 7.5,
 7.8,
@@ -3528,7 +3526,7 @@ temp <- stats::ts(c(
 4.4,
 3.5,
 4.2,
-5.0,
+5,
 5.2,
 5.5,
 3.6,
@@ -3542,14 +3540,14 @@ temp <- stats::ts(c(
 6.9,
 4.8,
 5.8,
-6.0,
+6,
 2.6,
 -1.7,
 -0.8,
 -0.8,
 0.1,
 -0.1,
-2.0,
+2,
 2.6,
 3.8,
 7.3,
@@ -3571,7 +3569,7 @@ temp <- stats::ts(c(
 1.1,
 0.9,
 2.1,
-1.0,
+1,
 0.6,
 5.3,
 1.7,
@@ -3610,14 +3608,14 @@ temp <- stats::ts(c(
 -7.1,
 -7.5,
 -4.7,
--5.0,
+-5,
 -6.4,
 -8.5,
 -10.4,
 -15.2,
 -10.6,
 -9.3,
--8.0,
+-8,
 -7.9,
 -7.8,
 -8.9,
@@ -3629,15 +3627,15 @@ temp <- stats::ts(c(
 -1.3,
 -6.1,
 -5.7,
--5.0,
+-5,
 -4.2,
 -3.8,
 -6.3,
--7.0,
+-7,
 -6.2,
 -6.3,
 -5.4,
--11.0,
+-11,
 -8.5,
 -5.6,
 -9.5,
@@ -3658,7 +3656,7 @@ temp <- stats::ts(c(
 -6.2,
 -5.2,
 -7.4,
--3.0,
+-3,
 -4.1,
 -6.5,
 -4.9,
@@ -3725,15 +3723,15 @@ temp <- stats::ts(c(
 -5.6,
 -7.7,
 -10.7,
--7.0,
+-7,
 -0.1,
 -0.5,
--6.0,
+-6,
 -2.7,
 1.3,
 1.3,
-1.0,
-1.0,
+1,
+1,
 0.4,
 1.6,
 -0.2,
@@ -3753,10 +3751,10 @@ temp <- stats::ts(c(
 -15.8,
 -16.6,
 -15.8,
--5.0,
--8.0,
+-5,
+-8,
 -6.5,
--7.0,
+-7,
 -7.1,
 -1.5,
 2.2,
@@ -3775,7 +3773,7 @@ temp <- stats::ts(c(
 1.4,
 1.9,
 1.7,
-0.0,
+0,
 -1.6,
 -8.2,
 -7.3,
@@ -3798,8 +3796,8 @@ temp <- stats::ts(c(
 1.7,
 2.4,
 1.9,
-0.0,
-2.0,
+0,
+2,
 3.8,
 2.9,
 3.3,
@@ -3808,7 +3806,7 @@ temp <- stats::ts(c(
 2.7,
 2.9,
 1.5,
-2.0,
+2,
 -0.5,
 -1.4,
 -0.7,
@@ -3826,13 +3824,13 @@ temp <- stats::ts(c(
 -1.7,
 -0.9,
 2.6,
-3.0,
+3,
 6.9,
 6.5,
-6.0,
+6,
 3.9,
 4.2,
-6.0,
+6,
 6.7,
 5.6,
 5.7,
@@ -3865,8 +3863,8 @@ temp <- stats::ts(c(
 9.7,
 10.5,
 11.5,
-11.0,
-10.0,
+11,
+10,
 8.3,
 6.4,
 6.8,
@@ -3880,7 +3878,7 @@ temp <- stats::ts(c(
 4.5,
 3.4,
 2.4,
-4.0,
+4,
 4.2,
 5.2,
 5.3,
@@ -3889,7 +3887,7 @@ temp <- stats::ts(c(
 6.1,
 8.5,
 6.7,
-2.0,
+2,
 1.8,
 2.8,
 3.8,
@@ -3903,12 +3901,12 @@ temp <- stats::ts(c(
 7.5,
 6.5,
 7.1,
-6.0,
+6,
 4.8,
 4.3,
 3.8,
 4.2,
-5.0,
+5,
 3.1,
 3.8,
 1.3,
@@ -3916,21 +3914,21 @@ temp <- stats::ts(c(
 4.7,
 7.5,
 8.5,
-8.0,
+8,
 6.6,
 7.3,
 7.3,
 8.7,
 7.5,
-5.0,
+5,
 2.1,
-2.0,
+2,
 2.2,
 4.2,
 3.3,
 2.4,
 1.2,
-0.0,
+0,
 -1.2,
 -0.3,
 2.9,
@@ -3947,8 +3945,8 @@ temp <- stats::ts(c(
 -0.9,
 -3.5,
 -1.4,
--5.0,
--7.0,
+-5,
+-7,
 -7.3,
 -10.2,
 -8.3,
@@ -4013,8 +4011,8 @@ temp <- stats::ts(c(
 -12.4,
 -22.4,
 -21.4,
--14.0,
--13.0,
+-14,
+-13,
 -15.8,
 -15.2,
 -16.6,
@@ -4022,7 +4020,7 @@ temp <- stats::ts(c(
 -4.8,
 -5.3,
 -8.8,
--8.0,
+-8,
 -12.3,
 -13.3,
 -10.7,
@@ -4036,7 +4034,7 @@ temp <- stats::ts(c(
 -3.2,
 -2.7,
 -4.1,
--2.0,
+-2,
 -3.5,
 -3.3,
 -3.9,
@@ -4048,7 +4046,7 @@ temp <- stats::ts(c(
 -1.9,
 -4.3,
 -0.6,
--2.0,
+-2,
 -3.4,
 -6.2,
 -4.7,
@@ -4074,7 +4072,7 @@ temp <- stats::ts(c(
 -15.2,
 -12.8,
 -1.5,
--1.4,
+-4.1,
 -3.5,
 -0.7,
 -3.4,
@@ -4083,12 +4081,12 @@ temp <- stats::ts(c(
 -1.9,
 -0.4,
 -0.7,
--3.0,
+-3,
 -0.4,
 -5.4,
 -9.8,
 -1.5,
-1.0,
+1,
 0.5,
 0.1,
 -0.7,
@@ -4098,7 +4096,7 @@ temp <- stats::ts(c(
 0.6,
 0.2,
 -0.8,
--3.0,
+-3,
 -4.3,
 -4.7,
 -4.1,
@@ -4114,12 +4112,12 @@ temp <- stats::ts(c(
 -1.8,
 -0.5,
 1.6,
-1.0,
+1,
 1.6,
 0.2,
 -1.9,
 -1.9,
-2.0,
+2,
 2.1,
 2.1,
 0.9,
@@ -4131,7 +4129,7 @@ temp <- stats::ts(c(
 0.8,
 2.3,
 2.1,
-2.0,
+2,
 2.1,
 1.8,
 2.5,
@@ -4153,7 +4151,7 @@ temp <- stats::ts(c(
 1.9,
 1.4,
 0.3,
-0.0,
+0,
 0.1,
 2.7,
 5.5,
@@ -4166,12 +4164,12 @@ temp <- stats::ts(c(
 5.3,
 4.4,
 5.6,
-5.0,
+5,
 2.7,
 4.6,
 5.2,
 4.7,
-2.0,
+2,
 -0.9,
 0.6,
 1.6,
@@ -4185,40 +4183,40 @@ temp <- stats::ts(c(
 4.4,
 3.9,
 1.2,
-2.0,
+2,
 3.1,
-4.0,
+4,
 6.9,
 6.8,
 3.4,
 4.2,
 3.3,
-3.0,
-2.0,
-3.0,
+3,
+2,
+3,
 5.9,
 8.8,
 13.1,
 13.9,
 12.4,
-12.0,
+12,
 10.1,
 6.3,
-3.0,
+3,
 3.1,
 4.2,
 3.9,
 5.1,
 6.3,
 6.3,
-3.0,
+3,
 7.4,
 7.7,
 9.8,
 10.3,
 9.5,
 8.2,
-4.0,
+4,
 6.9,
 8.3,
 8.5,
@@ -4234,9 +4232,9 @@ temp <- stats::ts(c(
 10.9,
 9.7,
 11.5,
-9.0,
+9,
 3.5,
-4.0,
+4,
 3.3,
 6.1,
 5.7,
@@ -4249,11 +4247,11 @@ temp <- stats::ts(c(
 9.2,
 10.7,
 9.3,
-10.0,
+10,
 7.4,
 6.6,
 5.5,
-6.0,
+6,
 6.8,
 6.3,
 6.3,
@@ -4266,11 +4264,11 @@ temp <- stats::ts(c(
 -0.4,
 1.2,
 2.1,
-5.0,
+5,
 5.8,
 8.4,
 6.3,
-9.0,
+9,
 7.8,
 5.9,
 5.6,
@@ -4295,9 +4293,9 @@ temp <- stats::ts(c(
 -4.6,
 -3.4,
 -3.2,
--5.0,
+-5,
 -4.7,
--3.0,
+-3,
 -0.8,
 -0.2,
 0.1,
@@ -4305,15 +4303,15 @@ temp <- stats::ts(c(
 0.3,
 -2.7,
 -2.3,
--2.0,
--1.0,
+-2,
+-1,
 -0.6,
 0.9,
 2.1,
 2.5,
 5.3,
 4.2,
-2.0,
+2,
 0.1,
 1.4,
 -1.4,
@@ -4333,7 +4331,7 @@ temp <- stats::ts(c(
 -1.1,
 -0.6,
 -0.1,
-2.0,
+2,
 0.5,
 -1.3,
 0.3,
@@ -4344,7 +4342,7 @@ temp <- stats::ts(c(
 -5.8,
 -4.2,
 -4.6,
--4.0,
+-4,
 -6.1,
 -8.6,
 -8.7,
@@ -4352,12 +4350,12 @@ temp <- stats::ts(c(
 -5.8,
 -4.6,
 -2.6,
--2.0,
+-2,
 -1.8,
 -2.8,
 -3.2,
 -5.9,
--7.0,
+-7,
 -1.8,
 -2.6,
 -3.5,
@@ -4380,7 +4378,7 @@ temp <- stats::ts(c(
 -12.7,
 -13.2,
 -12.7,
--17.0,
+-17,
 -19.4,
 -11.6,
 -7.3,
@@ -4391,5 +4389,5 @@ temp <- stats::ts(c(
 -6.8,
 -2.4,
 -5.4),
-start=c(1972,1),end=c(1974,365),frequency=365)
+start=c(1972,1),frequency=365)
 ice.river <- stats::ts.union (flow.vat, flow.jok, prec,temp)
